import axios from 'axios'
import qs from 'qs'
import md5 from 'blueimp-md5'
const httpRequest = axios.create({
  timeout: 60000,
  withCredentials: true
})

// 请求拦截
httpRequest.interceptors.request.use(
  function(config) {
    const option = window.messageOption
    config.baseURL = option.baseURL || 'https://test-microservices-message-service-api.ezijing.com'

    // 默认参数
    const defaultParams = {
      source: option.source,
      timestamp: parseInt(Date.now() / 1000),
      nonce: Math.random()
        .toString(36)
        .slice(-8)
    }
    // 接口请求参数
    let params = config.params || config.data

    // 排序
    function alphabeticalSort(a, b) {
      return a.localeCompare(b)
    }
    // https://gitlab.ezijing.com/root/api-documents/-/blob/master/messages/api/%E7%8E%AF%E5%A2%83%E8%AF%B4%E6%98%8E.md#%E6%8E%A5%E5%8F%A3%E7%AD%BE%E5%90%8D
    params = Object.assign({}, defaultParams, params)
    let str = qs.stringify(Object.assign({}, params, { salt: 'n7xAav2tSjn9Ysnr' }), { sort: alphabeticalSort })
    params.signature = md5(str)
      .toString()
      .toUpperCase()

    if (config.method === 'post') {
      config.data = params
    } else {
      config.params = params
    }
    return config
  },
  function(error) {
    return Promise.reject(error)
  }
)

// 响应拦截
httpRequest.interceptors.response.use(
  function(response) {
    return response.data.code ? Promise.reject(response.data) : response.data.data
  },
  function(error) {
    return Promise.reject(error)
  }
)

export default httpRequest
